@@ -1,6 +1,6 @@
 use crate::app::AragogCliApp;
 use clap::{App, ArgEnum, IntoApp, Parser};
-use clap_generate::generators::*;
+use clap_generate::generators::{Bash, Elvish, Fish, PowerShell, Zsh};
 use clap_generate::{generate, Generator};
 
 #[derive(Parser, Debug)]
